@@ -6,7 +6,7 @@ use std::time::{SystemTime, UNIX_EPOCH};
 
 use stellar_notation::{
     StellarObject, StellarValue,
-    serialize_stellar_objects, deserialize_stellar_objects
+    byte_encode, byte_decode
 };
 
 use crate::Store;
@@ -39,11 +39,13 @@ pub fn perform(mut store: Store) -> Result<(), Box<dyn Error>> {
 
                 let level_file_objects_vec: Vec<Vec<StellarObject>> = level_files.iter()
                     .map(|x| fs::read(x).unwrap())
-                    .map(|x| deserialize_stellar_objects(&x))
+                    .map(|x| byte_decode::list(&x))
                     .collect();
 
                 let mut level_objects: Vec<StellarObject> = level_file_objects_vec.concat();
 
+                let initial_grave_size = store.grave.len();
+
                 let grave_list = store.grave.clone();
 
                 for i in grave_list {
@@ -66,13 +68,13 @@ pub fn perform(mut store: Store) -> Result<(), Box<dyn Error>> {
                     }
                 }
 
-                if store.grave.len() > 0 {
+                if store.grave.len() != initial_grave_size {
 
                     let grave_objects: Vec<StellarObject> = store.grave.iter()
                     .map(|x| StellarObject(x.to_string(), StellarValue::UInt8(0)))
                     .collect();
 
-                    let grave_serialized = serialize_stellar_objects(&grave_objects);
+                    let grave_serialized = byte_encode::list(grave_objects);
 
                     let grave_path = format!("{}/grave.stellar", &store_path);
 
@@ -80,10 +82,7 @@ pub fn perform(mut store: Store) -> Result<(), Box<dyn Error>> {
 
                 }
 
-                level_objects.sort_by_key(|x| x.clone().0);
-                level_objects.dedup_by_key(|x| x.clone().0);
-
-                let objects_serialized: Vec<u8> = serialize_stellar_objects(&level_objects);
+                let objects_serialized: Vec<u8> = byte_encode::list(level_objects.clone());
 
                 let current_time = SystemTime::now().duration_since(UNIX_EPOCH)?.as_millis();
 
@@ -106,11 +105,11 @@ pub fn perform(mut store: Store) -> Result<(), Box<dyn Error>> {
 
                 let bloom_filters = fs::read(&bloom_filters_path)?;
 
-                let mut deserialize_bloom_filters = deserialize_stellar_objects(&bloom_filters);
+                let mut deserialize_bloom_filters = byte_decode::list(&bloom_filters);
 
                 deserialize_bloom_filters.push(new_bloom_filter_object);
 
-                let new_bloom_filters = serialize_stellar_objects(&deserialize_bloom_filters);
+                let new_bloom_filters = byte_encode::list(deserialize_bloom_filters);
 
                 fs::write(&bloom_filters_path, &new_bloom_filters)?;
 
@@ -122,11 +121,11 @@ pub fn perform(mut store: Store) -> Result<(), Box<dyn Error>> {
 
                 let table_locations = fs::read(&table_locations_path)?;
 
-                let mut deserialize_table_locations = deserialize_stellar_objects(&table_locations);
+                let mut deserialize_table_locations = byte_decode::list(&table_locations);
 
                 deserialize_table_locations.push(new_table_location_object);
 
-                let new_table_locations = serialize_stellar_objects(&deserialize_table_locations);
+                let new_table_locations = byte_encode::list(deserialize_table_locations);
 
                 fs::write(&table_locations_path, &new_table_locations)?;
 
